@@ -8,7 +8,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-12-01'; # DATE
 our $DIST = 'App-MineralUtils'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 our %SPEC;
 
@@ -291,6 +291,11 @@ MARKDOWN
             args=>{quantity=>'350 mg-mg-oxide-anhydrous', to_unit=>'mg-mg-elem'},
             summary=>'How much of magnesium oxide provides 350 mg of elemental magnesium?',
         },
+        {
+            src_plang => 'bash',
+            src=>'[[prog]] | td sort -- -pct_mg',
+            summary=>'Sort by highest magnesium content',
+        },
     ],
 };
 sub convert_magnesium_unit {
@@ -872,7 +877,7 @@ App::MineralUtils - Utilities related to mineral supplements
 
 =head1 VERSION
 
-This document describes version 0.017 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2024-12-01.
+This document describes version 0.018 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2024-12-01.
 
 =head1 DESCRIPTION
 
@@ -974,13 +979,13 @@ Result:
    ],
    {
      "table.fields"        => ["amount", "pct_ca", "unit", "summary"],
-     "table.field_aligns"  => ["number", "number", "left", "left"],
      "table.field_formats" => [
-                                ["number", { thousands_sep => "", precision => 3 }],
                                 ["number", { precision => 3, thousands_sep => "" }],
+                                ["number", { thousands_sep => "", precision => 3 }],
                                 undef,
                                 undef,
                               ],
+     "table.field_aligns"  => ["number", "number", "left", "left"],
    },
  ]
 
@@ -1055,13 +1060,13 @@ Result:
    ],
    {
      "table.fields"        => ["amount", "pct_fe", "unit", "summary"],
+     "table.field_aligns"  => ["number", "number", "left", "left"],
      "table.field_formats" => [
-                                ["number", { precision => 3, thousands_sep => "" }],
                                 ["number", { thousands_sep => "", precision => 3 }],
+                                ["number", { precision => 3, thousands_sep => "" }],
                                 undef,
                                 undef,
                               ],
-     "table.field_aligns"  => ["number", "number", "left", "left"],
    },
  ]
 
@@ -1327,14 +1332,14 @@ Result:
      },
    ],
    {
+     "table.fields"        => ["amount", "pct_mg", "unit", "summary"],
+     "table.field_aligns"  => ["number", "number", "left", "left"],
      "table.field_formats" => [
                                 ["number", { precision => 3, thousands_sep => "" }],
                                 ["number", { thousands_sep => "", precision => 3 }],
                                 undef,
                                 undef,
                               ],
-     "table.field_aligns"  => ["number", "number", "left", "left"],
-     "table.fields"        => ["amount", "pct_mg", "unit", "summary"],
    },
  ]
 
@@ -1596,13 +1601,13 @@ Result:
    ],
    {
      "table.fields"        => ["amount", "pct_na", "unit", "summary"],
-     "table.field_aligns"  => ["number", "number", "left", "left"],
      "table.field_formats" => [
                                 ["number", { precision => 3, thousands_sep => "" }],
-                                ["number", { precision => 3, thousands_sep => "" }],
+                                ["number", { thousands_sep => "", precision => 3 }],
                                 undef,
                                 undef,
                               ],
+     "table.field_aligns"  => ["number", "number", "left", "left"],
    },
  ]
 
